@@ -1,21 +1,7 @@
 /*
- * Copyright 2015 Aleix Pol Gonzalez <aleixpol@kde.org>
+ * SPDX-FileCopyrightText: 2015 Aleix Pol Gonzalez <aleixpol@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include <QCryptographicHash>
@@ -31,6 +17,7 @@
 #include "interfaces/notificationsmodel.h"
 #include "interfaces/dbusinterfaces.h"
 #include "interfaces/dbushelpers.h"
+#include "interfaces/conversationmessage.h"
 #include "kdeconnect-version.h"
 
 #include <dbushelper.h>
@@ -66,6 +53,7 @@ int main(int argc, char** argv)
     parser.addOption(QCommandLineOption(QStringLiteral("lock"), i18n("Lock the specified device")));
     parser.addOption(QCommandLineOption(QStringLiteral("send-sms"), i18n("Sends an SMS. Requires destination"), i18n("message")));
     parser.addOption(QCommandLineOption(QStringLiteral("destination"), i18n("Phone number to send the message"), i18n("phone number")));
+    //parser.addOption(QCommandLineOption(QStringLiteral("attachment"), i18n("File urls to send attachments with the message (can be passed multiple times)"), i18n("file urls"))); // Disabling this until we have Android support
     parser.addOption(QCommandLineOption(QStringList(QStringLiteral("device")) << QStringLiteral("d"), i18n("Device ID"), QStringLiteral("dev")));
     parser.addOption(QCommandLineOption(QStringList(QStringLiteral("name")) << QStringLiteral("n"), i18n("Device Name"), QStringLiteral("name")));
     parser.addOption(QCommandLineOption(QStringLiteral("encryption-info"), i18n("Get encryption info about said device")));
@@ -83,7 +71,6 @@ int main(int argc, char** argv)
     parser.addOption(deviceAutocomplete);
     about.setupCommandLine(&parser);
 
-    parser.addHelpOption();
     parser.process(app);
     about.processCommandLine(&parser);
 
@@ -167,7 +154,7 @@ int main(int argc, char** argv)
         }
 
         //Exit with 1 if we didn't find a device
-        return int(!devices.isEmpty());
+        return int(devices.isEmpty());
     } else if(parser.isSet(QStringLiteral("refresh"))) {
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect"), QStringLiteral("org.kde.kdeconnect.daemon"), QStringLiteral("forceOnNetworkChange"));
         blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
@@ -182,8 +169,8 @@ int main(int argc, char** argv)
             }
         }
         if(device.isEmpty()) {
-            QTextStream(stderr) << i18n("No device specified") << endl;
-            parser.showHelp(1);
+            QTextStream(stderr) << i18n("No device specified: Use -d <Device ID> or -n <Device Name> to specify a device. \nDevice ID's and names may be found using \"kdeconnect-cli -l\" \nView complete help with --help option") << endl;
+            return 1;
         }
 
         if (!blockOnReply<QStringList>(iface.devices(false, false)).contains(device)) {
@@ -262,9 +249,30 @@ int main(int argc, char** argv)
             blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
         } else if(parser.isSet(QStringLiteral("send-sms"))) {
             if (parser.isSet(QStringLiteral("destination"))) {
-                QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/sms"), QStringLiteral("org.kde.kdeconnect.device.sms"), QStringLiteral("sendSms"));
-                msg.setArguments({ parser.value(QStringLiteral("destination")), parser.value(QStringLiteral("send-sms"))});
-                blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
+                qDBusRegisterMetaType<ConversationAddress>();
+                QVariantList addresses;
+
+                const QStringList addressList = parser.value(QStringLiteral("destination")).split(QRegularExpression(QStringLiteral("\\s+")));
+
+                for (const QString& input : addressList) {
+                    ConversationAddress address(input);
+                    addresses << QVariant::fromValue(address);
+                }
+
+                const QString message = parser.value(QStringLiteral("send-sms"));
+
+                const QStringList rawAttachmentUrlsList = parser.values(QStringLiteral("attachment"));
+
+                QVariantList attachments;
+                for (const QString& attachmentUrl : rawAttachmentUrlsList) {
+                    // TODO: Construct attachment objects from the list of Urls
+                    Q_UNUSED(attachmentUrl);
+                }
+
+                DeviceConversationsDbusInterface conversationDbusInterface(device);
+                auto reply = conversationDbusInterface.sendWithoutConversation(addresses, message, attachments);
+
+                reply.waitForFinished();
             } else {
                 QTextStream(stderr) << i18n("error: should specify the SMS's recipient by passing --destination <phone number>");
                 return 1;
