@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "daemon.h"
@@ -24,6 +10,7 @@
 #include <QNetworkAccessManager>
 #include <QDebug>
 #include <QPointer>
+#include <QProcess>
 
 #include "core_debug.h"
 #include "kdeconnectconfig.h"
@@ -93,6 +80,11 @@ void Daemon::init()
         #endif
     }
 
+    //Register on DBus
+    qDBusRegisterMetaType< QMap<QString,QString> >();
+    DBusHelper::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
+    DBusHelper::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
+
     //Read remembered paired devices
     const QStringList& list = KdeConnectConfig::instance().trustedDevices();
     for (const QString& id : list) {
@@ -106,11 +98,6 @@ void Daemon::init()
         a->onStart();
     }
 
-    //Register on DBus
-    qDBusRegisterMetaType< QMap<QString,QString> >();
-    DBusHelper::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
-    DBusHelper::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
-
     NotificationServerInfo::instance().init();
 
     qCDebug(KDECONNECT_CORE) << "Daemon started";
@@ -252,12 +239,31 @@ void Daemon::onDeviceStatusChanged()
 
 void Daemon::setAnnouncedName(const QString& name)
 {
-    qCDebug(KDECONNECT_CORE()) << "Announcing name";
+    qCDebug(KDECONNECT_CORE) << "Announcing name";
     KdeConnectConfig::instance().setName(name);
     forceOnNetworkChange();
     Q_EMIT announcedNameChanged(name);
 }
 
+void Daemon::setCustomDevices(const QStringList& addresses)
+{
+    auto& config = KdeConnectConfig::instance();
+
+    auto customDevices = config.customDevices();
+    if (customDevices != addresses) {
+        qCDebug(KDECONNECT_CORE) << "Changed list of custom device addresses:" << addresses;
+        config.setCustomDevices(addresses);
+        Q_EMIT customDevicesChanged(addresses);
+
+        forceOnNetworkChange();
+    }
+}
+
+QStringList Daemon::customDevices() const
+{
+    return KdeConnectConfig::instance().customDevices();
+}
+
 QString Daemon::announcedName()
 {
     return KdeConnectConfig::instance().name();
@@ -326,3 +332,23 @@ QString Daemon::selfId() const
 {
     return KdeConnectConfig::instance().deviceId();
 }
+
+void Daemon::openConfiguration(const QString &deviceId, const QString &pluginId)
+{
+    QStringList args;
+
+    QString argument;
+
+    if (!deviceId.isEmpty()) {
+        args << QStringLiteral("--args");
+        argument = deviceId;
+
+        if (!pluginId.isEmpty()) {
+            argument += QLatin1Char(':') + pluginId;
+        }
+
+        args << argument;
+    }
+
+    QProcess::startDetached(QStringLiteral("kdeconnect-settings"), args);
+}
