@@ -1,28 +1,17 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "pluginloader.h"
 
+#include <QVector>
+#include <QPluginLoader>
 #include <KPluginMetaData>
 #include <KPluginLoader>
 #include <KPluginFactory>
+#include <QStaticPlugin>
 
 #include "core_debug.h"
 #include "device.h"
@@ -39,10 +28,24 @@ PluginLoader* PluginLoader::instance()
 
 PluginLoader::PluginLoader()
 {
+#ifdef SAILFISHOS
+    const QVector<QStaticPlugin> staticPlugins = QPluginLoader::staticPlugins();
+    for (auto& staticPlugin : staticPlugins) {
+        QJsonObject jsonMetadata = staticPlugin.metaData().value(QStringLiteral("MetaData")).toObject();
+        KPluginMetaData metadata(jsonMetadata, QString());
+        if (metadata.serviceTypes().contains(QStringLiteral("KdeConnect/Plugin"))) {
+            plugins.insert(metadata.pluginId(), metadata);
+            pluginsFactories.insert(
+                metadata.pluginId(),
+                qobject_cast<KPluginFactory*>(staticPlugin.instance()));
+        }
+    }
+#else
     const QVector<KPluginMetaData> data = KPluginLoader::findPlugins(QStringLiteral("kdeconnect/"));
     for (const KPluginMetaData& metadata : data) {
         plugins[metadata.pluginId()] = metadata;
     }
+#endif
 }
 
 QStringList PluginLoader::getPluginList() const
@@ -65,12 +68,16 @@ KdeConnectPlugin* PluginLoader::instantiatePluginForDevice(const QString& plugin
         return ret;
     }
 
+#ifdef SAILFISHOS
+    KPluginFactory* factory = pluginsFactories.value(pluginName);
+#else
     KPluginLoader loader(service.fileName());
     KPluginFactory* factory = loader.factory();
     if (!factory) {
         qCDebug(KDECONNECT_CORE) << "KPluginFactory could not load the plugin:" << service.pluginId() << loader.errorString();
         return ret;
     }
+#endif
 
     const QStringList outgoingInterfaces = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-OutgoingPacketType"));
 
