@@ -1,21 +1,7 @@
 /*
- * Copyright 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
+ * SPDX-FileCopyrightText: 2016 Aleix Pol Gonzalez <aleixpol@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "deviceindicator.h"
@@ -32,13 +18,15 @@ Q_OBJECT
 public:
     BatteryAction(DeviceDbusInterface* device)
         : QAction(nullptr)
-        , m_batteryIface(new DeviceBatteryDbusInterface(device->id(), this))
+        , m_batteryIface(device->id())
     {
-        setWhenAvailable(m_batteryIface->charge(), [this](int charge) { setCharge(charge); }, this);
-        setWhenAvailable(m_batteryIface->isCharging(), [this](bool charging) { setCharging(charging); }, this);
+        setCharge(m_batteryIface.charge());
+        setCharging(m_batteryIface.isCharging());
 
-        connect(m_batteryIface, SIGNAL(chargeChanged(int)), this, SLOT(setCharge(int)));
-        connect(m_batteryIface, SIGNAL(stateChanged(bool)), this, SLOT(setCharging(bool)));
+        connect(&m_batteryIface, &BatteryDbusInterface::refreshedProxy, this, [this]{
+            setCharge(m_batteryIface.charge());
+            setCharging(m_batteryIface.isCharging());
+        });
 
         setIcon(QIcon::fromTheme(QStringLiteral("battery")));
 
@@ -59,7 +47,7 @@ private Q_SLOTS:
     void setCharging(bool charging) { m_charging = charging; update(); }
 
 private:
-    DeviceBatteryDbusInterface* m_batteryIface;
+    BatteryDbusInterface m_batteryIface;
     int m_charge = -1;
     bool m_charging = false;
 };
