@@ -1,27 +1,12 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "mpriscontrolplugin.h"
 
 #include <QDBusArgument>
-#include <QDBusInterface>
 #include <qdbusconnectioninterface.h>
 #include <QDBusReply>
 #include <QDBusMessage>
@@ -31,14 +16,14 @@
 
 #include <core/device.h>
 #include <dbushelper.h>
-#include "mprisdbusinterface.h"
-#include "propertiesdbusinterface.h"
+
+#include "dbusproperties.h"
+#include "mprisplayer.h"
+#include "mprisroot.h"
+#include "plugin_mpris_debug.h"
 
 K_PLUGIN_CLASS_WITH_JSON(MprisControlPlugin, "kdeconnect_mpriscontrol.json")
 
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_MPRIS, "kdeconnect.plugin.mpris")
-
-
 MprisPlayer::MprisPlayer(const QString& serviceName, const QString& dbusObjectPath, const QDBusConnection& busConnection)
     : m_serviceName(serviceName)
     , m_propertiesInterface(new OrgFreedesktopDBusPropertiesInterface(serviceName, dbusObjectPath, busConnection))
@@ -68,8 +53,10 @@ MprisControlPlugin::MprisControlPlugin(QObject* parent, const QVariantList& args
 // Copied from the mpris2 dataengine in the plasma-workspace repository
 void MprisControlPlugin::serviceOwnerChanged(const QString& serviceName, const QString& oldOwner, const QString& newOwner)
 {
-    if (!serviceName.startsWith(QLatin1String("org.mpris.MediaPlayer2.")))
-        return;
+    if (!serviceName.startsWith(QStringLiteral("org.mpris.MediaPlayer2."))) return;
+    if (serviceName.startsWith(QStringLiteral("org.mpris.MediaPlayer2.kdeconnect."))) return;
+    // playerctld is a only a proxy to other media players, and can thus safely be ignored
+    if (serviceName == QStringLiteral("org.mpris.MediaPlayer2.playerctld")) return;
 
     if (!oldOwner.isEmpty()) {
         qCDebug(KDECONNECT_PLUGIN_MPRIS) << "MPRIS service" << serviceName << "just went offline";
@@ -87,10 +74,9 @@ void MprisControlPlugin::addPlayer(const QString& service)
 {
     const QString mediaPlayerObjectPath = QStringLiteral("/org/mpris/MediaPlayer2");
 
-    // estimate identifier string
-    QDBusInterface mprisInterface(service, mediaPlayerObjectPath, QStringLiteral("org.mpris.MediaPlayer2"));
-    //FIXME: This call hangs and returns an empty string if KDED is still starting!
-    QString identity = mprisInterface.property("Identity").toString();
+    OrgMprisMediaPlayer2Interface iface(service, mediaPlayerObjectPath, DBusHelper::sessionBus());
+    QString identity = iface.identity();
+
     if (identity.isEmpty()) {
         identity = service.mid(sizeof("org.mpris.MediaPlayer2"));
     }
@@ -361,10 +347,23 @@ void MprisControlPlugin::mprisPlayerMetadataToNetworkPacket(NetworkPacket& np, c
     QString artist = nowPlayingMap[QStringLiteral("xesam:artist")].toString();
     QString album = nowPlayingMap[QStringLiteral("xesam:album")].toString();
     QString albumArtUrl = nowPlayingMap[QStringLiteral("mpris:artUrl")].toString();
+    QUrl fileUrl = nowPlayingMap[QStringLiteral("xesam:url")].toUrl();
+
+    if (title.isEmpty() && artist.isEmpty() && fileUrl.isLocalFile()) {
+        title = fileUrl.fileName();
+
+        QStringList splitUrl = fileUrl.path().split(QDir::separator());
+        if (album.isEmpty() && splitUrl.size() > 1) {
+            album = splitUrl.at(splitUrl.size() - 2);
+        }
+    }
+
     QString nowPlaying = title;
+
     if (!artist.isEmpty()) {
         nowPlaying = artist + QStringLiteral(" - ") + title;
     }
+
     np.set(QStringLiteral("title"), title);
     np.set(QStringLiteral("artist"), artist);
     np.set(QStringLiteral("album"), album);
@@ -377,6 +376,7 @@ void MprisControlPlugin::mprisPlayerMetadataToNetworkPacket(NetworkPacket& np, c
         length = -1;
     }
     np.set(QStringLiteral("length"), length);
+    np.set(QStringLiteral("url"), fileUrl);
 }
 
 #include "mpriscontrolplugin.moc"
