@@ -1,22 +1,8 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
- * Copyright 2019 Piyush Aggarwal <piyushaggarwal002@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2019 Piyush Aggarwal <piyushaggarwal002@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "pausemusicplugin-win.h"
@@ -55,7 +41,7 @@ PauseMusicPlugin::~PauseMusicPlugin()
 bool PauseMusicPlugin::receivePacket(const NetworkPacket& np)
 {
 
-    bool pauseOnlyWhenTalking = config()->get(QStringLiteral("conditionTalking"), false);
+    bool pauseOnlyWhenTalking = config()->getBool(QStringLiteral("conditionTalking"), false);
 
     if (pauseOnlyWhenTalking) {
         if (np.get<QString>(QStringLiteral("event")) != QLatin1String("talking")) {
@@ -70,10 +56,10 @@ bool PauseMusicPlugin::receivePacket(const NetworkPacket& np)
 
     bool pauseConditionFulfilled = !np.get<bool>(QStringLiteral("isCancel"));
 
-    bool pause = config()->get(QStringLiteral("actionPause"), false);
-    bool mute = config()->get(QStringLiteral("actionMute"), true);
+    bool pause = config()->getBool(QStringLiteral("actionPause"), false);
+    bool mute = config()->getBool(QStringLiteral("actionMute"), true);
 
-    const bool autoResume = config()->get(QStringLiteral("actionResume"), true);
+    const bool autoResume = config()->getBool(QStringLiteral("actionResume"), true);
 
     if (pauseConditionFulfilled) {
 
