@@ -1,51 +1,39 @@
 /**
- * Copyright 2015 Holger Kaelberer <holger.k@elberer.de>
+ * SPDX-FileCopyrightText: 2015 Holger Kaelberer <holger.k@elberer.de>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
+#include "notificationslistener.h"
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusArgument>
+#include <QDBusInterface>
+#include <QDBusArgument>
 #include <QtDebug>
-#include <QLoggingCategory>
 #include <QStandardPaths>
 #include <QImage>
 #include <KConfig>
 #include <KConfigGroup>
-
 #include <kiconloader.h>
 #include <kicontheme.h>
 
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
 
-#include "notificationslistener.h"
+#include <dbushelper.h>
+
 #include "sendnotificationsplugin.h"
-#include "sendnotification_debug.h"
+#include "plugin_sendnotification_debug.h"
 #include "notifyingapplication.h"
 
+//In older Qt released, qAsConst isnt available
+#include "qtcompat_p.h"
+
 NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
     : QDBusAbstractAdaptor(aPlugin),
       m_plugin(aPlugin)
 {
     qRegisterMetaTypeStreamOperators<NotifyingApplication>("NotifyingApplication");
 
-    bool ret = QDBusConnection::sessionBus()
+    bool ret = DBusHelper::sessionBus()
                 .registerObject(QStringLiteral("/org/freedesktop/Notifications"),
                                 this,
                                 QDBusConnection::ExportScriptableContents);
@@ -53,7 +41,7 @@ NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
         qCWarning(KDECONNECT_PLUGIN_SENDNOTIFICATION)
                 << "Error registering notifications listener for device"
                 << m_plugin->device()->name() << ":"
-                << QDBusConnection::sessionBus().lastError();
+                << DBusHelper::sessionBus().lastError();
     else
         qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION)
                 << "Registered notifications listener for device"
@@ -62,7 +50,7 @@ NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
     QDBusInterface iface(QStringLiteral("org.freedesktop.DBus"), QStringLiteral("/org/freedesktop/DBus"),
                          QStringLiteral("org.freedesktop.DBus"));
     iface.call(QStringLiteral("AddMatch"),
-               "interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'");
+               QStringLiteral("interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'"));
 
     setTranslatedAppName();
     loadApplications();
@@ -76,8 +64,8 @@ NotificationsListener::~NotificationsListener()
     QDBusInterface iface(QStringLiteral("org.freedesktop.DBus"), QStringLiteral("/org/freedesktop/DBus"),
                          QStringLiteral("org.freedesktop.DBus"));
     QDBusMessage res = iface.call(QStringLiteral("RemoveMatch"),
-                                  "interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'");
-    QDBusConnection::sessionBus().unregisterObject(QStringLiteral("/org/freedesktop/Notifications"));
+                                  QStringLiteral("interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'"));
+    DBusHelper::sessionBus().unregisterObject(QStringLiteral("/org/freedesktop/Notifications"));
 }
 
 void NotificationsListener::setTranslatedAppName()
@@ -100,8 +88,9 @@ void NotificationsListener::loadApplications()
     const QVariantList list = m_plugin->config()->getList(QStringLiteral("applications"));
     for (const auto& a : list) {
         NotifyingApplication app = a.value<NotifyingApplication>();
-        if (!m_applications.contains(app.name))
+        if (!m_applications.contains(app.name)) {
             m_applications.insert(app.name, app);
+        }
     }
     //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Loaded" << applications.size() << " applications";
 }
@@ -169,7 +158,7 @@ QSharedPointer<QIODevice> NotificationsListener::iconForIconName(const QString&
             // try falling back to hicolor theme:
             KIconTheme hicolor(QStringLiteral("hicolor"));
             if (hicolor.isValid()) {
-                iconPath = hicolor.iconPath(iconName + ".png", size, KIconLoader::MatchBest);
+                iconPath = hicolor.iconPath(iconName + QStringLiteral(".png"), size, KIconLoader::MatchBest);
                 //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Found non-png icon in default theme trying fallback to hicolor:" << iconPath;
             }
         }
@@ -179,6 +168,7 @@ QSharedPointer<QIODevice> NotificationsListener::iconForIconName(const QString&
         return QSharedPointer<QIODevice>(new QFile(iconPath));
     return QSharedPointer<QIODevice>();
 }
+
 uint NotificationsListener::Notify(const QString& appName, uint replacesId,
                                    const QString& appIcon,
                                    const QString& summary, const QString& body,
@@ -208,13 +198,14 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
             list << QVariant::fromValue<NotifyingApplication>(a);
         m_plugin->config()->setList(QStringLiteral("applications"), list);
         //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Added new application to config:" << app;
-    } else
+    } else {
         app = m_applications.value(appName);
+    }
 
     if (!app.active)
         return 0;
 
-    if (timeout > 0 && m_plugin->config()->get(QStringLiteral("generalPersistent"), false))
+    if (timeout > 0 && m_plugin->config()->getBool(QStringLiteral("generalPersistent"), false))
         return 0;
 
     int urgency = -1;
@@ -224,11 +215,11 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
         if (!ok)
             urgency = -1;
     }
-    if (urgency > -1 && urgency < m_plugin->config()->get<int>(QStringLiteral("generalUrgency"), 0))
+    if (urgency > -1 && urgency < m_plugin->config()->getInt(QStringLiteral("generalUrgency"), 0))
         return 0;
 
     QString ticker = summary;
-    if (!body.isEmpty() && m_plugin->config()->get(QStringLiteral("generalIncludeBody"), true))
+    if (!body.isEmpty() && m_plugin->config()->getBool(QStringLiteral("generalIncludeBody"), true))
         ticker += QStringLiteral(": ") + body;
 
     if (app.blacklistExpression.isValid() &&
@@ -238,16 +229,16 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
 
     //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Sending notification from" << appName << ":" <<ticker << "; appIcon=" << appIcon;
     NetworkPacket np(PACKET_TYPE_NOTIFICATION, {
-        {"id", QString::number(replacesId > 0 ? replacesId : ++id)},
-        {"appName", appName},
-        {"ticker", ticker},
-        {"isClearable", timeout == 0}
+        {QStringLiteral("id"), QString::number(replacesId > 0 ? replacesId : ++id)},
+        {QStringLiteral("appName"), appName},
+        {QStringLiteral("ticker"), ticker},
+        {QStringLiteral("isClearable"), timeout == 0}
     });                                   // KNotifications are persistent if
                                           // timeout == 0, for other notifications
                                           // clearability is pointless
 
     // sync any icon data?
-    if (m_plugin->config()->get(QStringLiteral("generalSynchronizeIcons"), true)) {
+    if (m_plugin->config()->getBool(QStringLiteral("generalSynchronizeIcons"), true)) {
         QSharedPointer<QIODevice> iconSource;
         // try different image sources according to priorities in notifications-
         // spec version 1.2:
