@@ -1,21 +1,7 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef SHAREPLUGIN_H
@@ -23,8 +9,6 @@
 
 #include <QPointer>
 
-#include <KIO/Job>
-
 #include <core/kdeconnectplugin.h>
 #include <core/compositefiletransferjob.h>
 
@@ -57,7 +41,7 @@ Q_SIGNALS:
     Q_SCRIPTABLE void shareReceived(const QString& url);
 
 private:
-    void finished(KJob* job, const qint64 dateModified);
+    void finished(KJob* job, const qint64 dateModified, const bool open);
     void shareUrl(const QUrl& url, bool open);
     QUrl destinationDir() const;
     QUrl getFileDestination(const QString filename) const;
