@@ -1,29 +1,14 @@
 /**
- * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
- * Copyright 2018 Simon Redman <simon@ergotech.com>
+ * SPDX-FileCopyrightText: 2013 Albert Vaca <albertvaka@gmail.com>
+ * SPDX-FileCopyrightText: 2018 Simon Redman <simon@ergotech.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef TELEPHONYPLUGIN_H
 #define TELEPHONYPLUGIN_H
 
-#include <QLoggingCategory>
-#include <QDBusInterface>
+#include <QPointer>
 
 #include <KNotification>
 
@@ -45,8 +30,6 @@
 
 #define PACKET_TYPE_TELEPHONY_REQUEST_MUTE QStringLiteral("kdeconnect.telephony.request_mute")
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY)
-
 class TelephonyPlugin
     : public KdeConnectPlugin
 {
@@ -74,7 +57,9 @@ private:
      *  - Incoming call (with the option to mute the ringing)
      *  - Missed call
      */
-    KNotification* createNotification(const NetworkPacket& np);
+    void createNotification(const NetworkPacket& np);
+
+    QPointer<KNotification> m_currentCallNotification;
 };
 
 #endif
