@@ -1,36 +1,20 @@
 /**
- * Copyright 2015 Aleix Pol Gonzalez <aleixpol@kde.org>
+ * SPDX-FileCopyrightText: 2015 Aleix Pol Gonzalez <aleixpol@kde.org>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include <QSocketNotifier>
 #include <kdeconnectconfig.h>
 #include <backends/lan/uploadjob.h>
 #include <core/filetransferjob.h>
-#include <QApplication>
+#include <QCoreApplication>
 #include <QNetworkAccessManager>
 #include <QTest>
 #include <QTemporaryFile>
 #include <QSignalSpy>
 #include <QStandardPaths>
 
-#include <KIO/AccessManager>
-
 #include "core/daemon.h"
 #include "core/device.h"
 #include "core/kdeconnectplugin.h"
